@@ -2,7 +2,6 @@
 # Example package with a console entry point
 """Reads and formats data from the SWMM 5 output file."""
 
-from __future__ import absolute_import, print_function
 
 import copy
 import datetime
@@ -234,13 +233,11 @@ class SwmmExtract(object):
             )
         if errcode != 0:
             raise ValueError(
-                """
+                f"""
 *
-*   Error code "{0}" in output file indicates a problem with the run.
+*   Error code "{errcode}" in output file indicates a problem with the run.
 *
-""".format(
-                    errcode
-                )
+"""
             )
         if self.swmm_nperiods == 0:
             raise ValueError(
@@ -281,9 +278,7 @@ class SwmmExtract(object):
             for _ in range(j):
                 stringsize = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
                 self.names[i].append(
-                    struct.unpack("{0}s".format(stringsize), self.fp.read(stringsize))[
-                        0
-                    ]
+                    struct.unpack(f"{stringsize}s", self.fp.read(stringsize))[0]
                 )
 
         # Stupid Python 3
@@ -315,7 +310,7 @@ class SwmmExtract(object):
         # Read pollutant concentration codes
         # = Number of pollutants * 4 byte integers
         self.pollutant_codes = struct.unpack(
-            "{0}i".format(self.swmm_npolluts),
+            f"{self.swmm_npolluts}i",
             self.fp.read(self.swmm_npolluts * self.RECORDSIZE),
         )
 
@@ -330,52 +325,52 @@ class SwmmExtract(object):
         # subcatchments
         nsubprop = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.propcode[0] = struct.unpack(
-            "{0}i".format(nsubprop), self.fp.read(nsubprop * self.RECORDSIZE)
+            f"{nsubprop}i", self.fp.read(nsubprop * self.RECORDSIZE)
         )
         for i in range(self.swmm_nsubcatch):
             rprops = struct.unpack(
-                "{0}f".format(nsubprop), self.fp.read(nsubprop * self.RECORDSIZE)
+                f"{nsubprop}f", self.fp.read(nsubprop * self.RECORDSIZE)
             )
             self.prop[0].append(list(zip(self.propcode[0], rprops)))
 
         # nodes
         nnodeprop = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.propcode[1] = struct.unpack(
-            "{0}i".format(nnodeprop), self.fp.read(nnodeprop * self.RECORDSIZE)
+            f"{nnodeprop}i", self.fp.read(nnodeprop * self.RECORDSIZE)
         )
         for i in range(self.swmm_nnodes):
             rprops = struct.unpack(
-                "{0}f".format(nnodeprop), self.fp.read(nnodeprop * self.RECORDSIZE)
+                f"{nnodeprop}f", self.fp.read(nnodeprop * self.RECORDSIZE)
             )
             self.prop[1].append(list(zip(self.propcode[1], rprops)))
 
         # links
         nlinkprop = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.propcode[2] = struct.unpack(
-            "{0}i".format(nlinkprop), self.fp.read(nlinkprop * self.RECORDSIZE)
+            f"{nlinkprop}i", self.fp.read(nlinkprop * self.RECORDSIZE)
         )
         for i in range(self.swmm_nlinks):
             rprops = struct.unpack(
-                "{0}f".format(nlinkprop), self.fp.read(nlinkprop * self.RECORDSIZE)
+                f"{nlinkprop}f", self.fp.read(nlinkprop * self.RECORDSIZE)
             )
             self.prop[2].append(list(zip(self.propcode[2], rprops)))
 
         self.vars = {}
         self.swmm_nsubcatchvars = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.vars[0] = struct.unpack(
-            "{0}i".format(self.swmm_nsubcatchvars),
+            f"{self.swmm_nsubcatchvars}i",
             self.fp.read(self.swmm_nsubcatchvars * self.RECORDSIZE),
         )
 
         self.nnodevars = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.vars[1] = struct.unpack(
-            "{0}i".format(self.nnodevars),
+            f"{self.nnodevars}i",
             self.fp.read(self.nnodevars * self.RECORDSIZE),
         )
 
         self.nlinkvars = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.vars[2] = struct.unpack(
-            "{0}i".format(self.nlinkvars),
+            f"{self.nlinkvars}i",
             self.fp.read(self.nlinkvars * self.RECORDSIZE),
         )
 
@@ -383,7 +378,7 @@ class SwmmExtract(object):
 
         self.nsystemvars = struct.unpack("i", self.fp.read(self.RECORDSIZE))[0]
         self.vars[4] = struct.unpack(
-            "{0}i".format(self.nsystemvars),
+            f"{self.nsystemvars}i",
             self.fp.read(self.nsystemvars * self.RECORDSIZE),
         )
 
@@ -417,14 +412,12 @@ class SwmmExtract(object):
             typenumber = self.itemlist.index(itemtype)
         except ValueError:
             raise ValueError(
-                """
+                f"""
 *
-*   Type argument "{0}" is incorrect.
-*   Must be in "{1}".
+*   Type argument "{itemtype}" is incorrect.
+*   Must be in "{list(range(5)) + self.itemlist}".
 *
-""".format(
-                    itemtype, list(range(5)) + self.itemlist
-                )
+"""
             )
         return typenumber
 
@@ -434,27 +427,23 @@ class SwmmExtract(object):
             itemindex = self.names[self.itemtype].index(str(itemname))
         except (ValueError, KeyError):
             raise ValueError(
-                """
+                f"""
 *
-*   {0} was not found in "{1}" list.
+*   {itemname} was not found in "{itemtype}" list.
 *
-""".format(
-                    itemname, itemtype
-                )
+"""
             )
         return (itemname, itemindex)
 
     def get_swmm_results(self, itemtype, name, variableindex, period):
         if itemtype not in [0, 1, 2, 4]:
             raise ValueError(
-                """
+                f"""
 *
 *   Type must be one of subcatchment (0), node (1). link (2), or system (4).
-*   You gave "{0}".
+*   You gave "{itemtype}".
 *
-""".format(
-                    itemtype
-                )
+"""
             )
 
         _, itemindex = self.name_check(itemtype, name)
@@ -523,10 +512,10 @@ def catalog_cli(filename, itemtype="", tablefmt="csv_nos", header="default"):
 
     Parameters
     ----------
-    {filename}
-    {itemtype}
-    {tablefmt}
-    {header}
+    ${filename}
+    ${itemtype}
+    ${tablefmt}
+    ${header}
     """
     if header == "default":
         header = ["TYPE", "NAME", "VARIABLE"]
@@ -564,15 +553,15 @@ def listdetail_cli(filename, itemtype, name="", tablefmt="simple", header="defau
 
     Parameters
     ----------
-    {filename}
-    {itemtype}
+    ${filename}
+    ${itemtype}
     name : str
         [optional, default is '']
 
         Specific name to print only that entry.  This can be
         looked up using 'listvariables'.
-    {tablefmt}
-    {header}
+    ${tablefmt}
+    ${header}
     """
     tsutils._printiso(
         listdetail(filename, itemtype, name=name, header=header), tablefmt=tablefmt
@@ -611,7 +600,7 @@ def listdetail(filename, itemtype, name="", header="default"):
             cheader.append(head)
         else:
             cnt = cheader.count(head)
-            cheader.append("{0}.{1}".format(head, cnt))
+            cheader.append(f"{head}.{cnt}")
     df.columns = cheader
     return df
 
@@ -625,9 +614,9 @@ def listvariables_cli(filename, tablefmt="csv_nos", header="default"):
 
     Parameters
     ----------
-    {filename}
-    {tablefmt}
-    {header}
+    ${filename}
+    ${tablefmt}
+    ${header}
     """
 
     tsutils._printiso(listvariables(filename, header=header), tablefmt=tablefmt)
@@ -673,9 +662,9 @@ def stdtoswmm5_cli(start_date=None, end_date=None, input_ts="-"):
 
     Parameters
     ----------
-    {input_ts}
-    {start_date}
-    {end_date}
+    ${input_ts}
+    ${start_date}
+    ${end_date}
     """
     tsutils._printiso(
         stdtoswmm5(start_date=start_date, end_date=end_date, input_ts=input_ts)
@@ -727,8 +716,8 @@ def extract_cli(filename, *labels):
 
     Parameters
     ----------
-    {filename}
-    {labels}
+    ${filename}
+    ${labels}
 
     """
     tsutils._printiso(extract(filename, *labels))
@@ -739,10 +728,16 @@ def extract(filename, *labels):
     obj = SwmmExtract(filename)
     nlabels = []
 
-    if isinstance(labels, (list, tuple)) and len(labels) == 1:
-        labels = labels[0]
+    # Don't look at the following code. It's just a hack to get the
+    # labels to work with the old syntax.
+    labels = tsutils.make_list(labels, sep=" ", flat=True)
+    plabels = []
+    for plabel in labels:
+        plabels.append(tsutils.make_list(plabel, sep=",", flat=True))
+    plabels = tsutils.flatten(plabels)
+    plabels = [plabels[i : i + 3] for i in range(0, len(plabels), 3)]
 
-    for label in labels:
+    for label in plabels:
         words = tsutils.make_list(label, n=3)
         if None not in words:
             nlabels.append(words)
@@ -793,11 +788,7 @@ def extract(filename, *labels):
         jtsd.append(
             pd.DataFrame(
                 pd.Series(values, index=dates),
-                columns=[
-                    "{0}_{1}_{2}".format(
-                        itemtype, name, obj.varcode[typenumber][variableindex]
-                    )
-                ],
+                columns=[f"{itemtype}_{name}_{obj.varcode[typenumber][variableindex]}"],
             )
         )
     result = pd.concat(jtsd, axis=1).reindex(jtsd[0].index)
@@ -818,8 +809,8 @@ def extract_arr(filename, *labels):
 
     Parameters
     ----------
-    {filename}
-    {labels}
+    ${filename}
+    ${labels}
 
     """
     warnings.warn(
